AssetDetail class

Detailed information about an asset including analysis results.

Constructors

AssetDetail({required AssetInfo info, ImageInfo? imageInfo, List<AssetIssue>? issues})
Creates an asset detail instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
imageInfo ImageInfo?
Image metadata (dimensions, format, alpha), if available.
final
info AssetInfo
Basic file information.
final
issues List<AssetIssue>
Optimization issues detected for this asset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited